Snakecdysis package
===================

.. automodapi:: snakecdysis.cli_wrapper
    :include-all-objects:
    :inherited-members:
    :no-inheritance-diagram:



.. _snakecdysis:

.. automodapi:: snakecdysis.snake_wrapper
    :include-all-objects:
    :inherited-members:
    :no-inheritance-diagram:
    :skip: OrderedDict
    :skip: Path

